# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200240ResponseSnapshots(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'managed_for': 'str',
        'name': 'str',
        'display_name': 'str',
        'status': 'str',
        'cg_display_name': 'str',
        'cg_name': 'str',
        'pool_name': 'str',
        'application': 'str',
        'snapshot_set_id': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'volume_ext_name': 'str',
        'volume_display_name': 'str',
        'volume_capacity_mb': 'int'
    }

    attribute_map = {
        'managed_for': 'managed_for',
        'name': 'name',
        'display_name': 'display_name',
        'status': 'status',
        'cg_display_name': 'cg_display_name',
        'cg_name': 'cg_name',
        'pool_name': 'pool_name',
        'application': 'application',
        'snapshot_set_id': 'snapshot_set_id',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'volume_ext_name': 'volume_ext_name',
        'volume_display_name': 'volume_display_name',
        'volume_capacity_mb': 'volume_capacity_mb'
    }

    def __init__(self, managed_for=None, name=None, display_name=None, status=None, cg_display_name=None, cg_name=None, pool_name=None, application=None, snapshot_set_id=None, created_at=None, modified_at=None, volume_ext_name=None, volume_display_name=None, volume_capacity_mb=None, _configuration=None):  # noqa: E501
        """InlineResponse200240ResponseSnapshots - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._managed_for = None
        self._name = None
        self._display_name = None
        self._status = None
        self._cg_display_name = None
        self._cg_name = None
        self._pool_name = None
        self._application = None
        self._snapshot_set_id = None
        self._created_at = None
        self._modified_at = None
        self._volume_ext_name = None
        self._volume_display_name = None
        self._volume_capacity_mb = None
        self.discriminator = None

        if managed_for is not None:
            self.managed_for = managed_for
        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if status is not None:
            self.status = status
        if cg_display_name is not None:
            self.cg_display_name = cg_display_name
        if cg_name is not None:
            self.cg_name = cg_name
        if pool_name is not None:
            self.pool_name = pool_name
        if application is not None:
            self.application = application
        if snapshot_set_id is not None:
            self.snapshot_set_id = snapshot_set_id
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if volume_ext_name is not None:
            self.volume_ext_name = volume_ext_name
        if volume_display_name is not None:
            self.volume_display_name = volume_display_name
        if volume_capacity_mb is not None:
            self.volume_capacity_mb = volume_capacity_mb

    @property
    def managed_for(self):
        """Gets the managed_for of this InlineResponse200240ResponseSnapshots.  # noqa: E501


        :return: The managed_for of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._managed_for

    @managed_for.setter
    def managed_for(self, managed_for):
        """Sets the managed_for of this InlineResponse200240ResponseSnapshots.


        :param managed_for: The managed_for of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :type: str
        """

        self._managed_for = managed_for

    @property
    def name(self):
        """Gets the name of this InlineResponse200240ResponseSnapshots.  # noqa: E501


        :return: The name of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200240ResponseSnapshots.


        :param name: The name of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501


        :return: The display_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse200240ResponseSnapshots.


        :param display_name: The display_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def status(self):
        """Gets the status of this InlineResponse200240ResponseSnapshots.  # noqa: E501


        :return: The status of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse200240ResponseSnapshots.


        :param status: The status of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def cg_display_name(self):
        """Gets the cg_display_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501


        :return: The cg_display_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._cg_display_name

    @cg_display_name.setter
    def cg_display_name(self, cg_display_name):
        """Sets the cg_display_name of this InlineResponse200240ResponseSnapshots.


        :param cg_display_name: The cg_display_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :type: str
        """

        self._cg_display_name = cg_display_name

    @property
    def cg_name(self):
        """Gets the cg_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501


        :return: The cg_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._cg_name

    @cg_name.setter
    def cg_name(self, cg_name):
        """Sets the cg_name of this InlineResponse200240ResponseSnapshots.


        :param cg_name: The cg_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :type: str
        """

        self._cg_name = cg_name

    @property
    def pool_name(self):
        """Gets the pool_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501


        :return: The pool_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._pool_name

    @pool_name.setter
    def pool_name(self, pool_name):
        """Sets the pool_name of this InlineResponse200240ResponseSnapshots.


        :param pool_name: The pool_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :type: str
        """

        self._pool_name = pool_name

    @property
    def application(self):
        """Gets the application of this InlineResponse200240ResponseSnapshots.  # noqa: E501


        :return: The application of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._application

    @application.setter
    def application(self, application):
        """Sets the application of this InlineResponse200240ResponseSnapshots.


        :param application: The application of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :type: str
        """

        self._application = application

    @property
    def snapshot_set_id(self):
        """Gets the snapshot_set_id of this InlineResponse200240ResponseSnapshots.  # noqa: E501


        :return: The snapshot_set_id of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._snapshot_set_id

    @snapshot_set_id.setter
    def snapshot_set_id(self, snapshot_set_id):
        """Sets the snapshot_set_id of this InlineResponse200240ResponseSnapshots.


        :param snapshot_set_id: The snapshot_set_id of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :type: str
        """

        self._snapshot_set_id = snapshot_set_id

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse200240ResponseSnapshots.  # noqa: E501


        :return: The created_at of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse200240ResponseSnapshots.


        :param created_at: The created_at of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse200240ResponseSnapshots.  # noqa: E501


        :return: The modified_at of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse200240ResponseSnapshots.


        :param modified_at: The modified_at of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def volume_ext_name(self):
        """Gets the volume_ext_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501


        :return: The volume_ext_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._volume_ext_name

    @volume_ext_name.setter
    def volume_ext_name(self, volume_ext_name):
        """Sets the volume_ext_name of this InlineResponse200240ResponseSnapshots.


        :param volume_ext_name: The volume_ext_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :type: str
        """

        self._volume_ext_name = volume_ext_name

    @property
    def volume_display_name(self):
        """Gets the volume_display_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501


        :return: The volume_display_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._volume_display_name

    @volume_display_name.setter
    def volume_display_name(self, volume_display_name):
        """Sets the volume_display_name of this InlineResponse200240ResponseSnapshots.


        :param volume_display_name: The volume_display_name of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :type: str
        """

        self._volume_display_name = volume_display_name

    @property
    def volume_capacity_mb(self):
        """Gets the volume_capacity_mb of this InlineResponse200240ResponseSnapshots.  # noqa: E501


        :return: The volume_capacity_mb of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :rtype: int
        """
        return self._volume_capacity_mb

    @volume_capacity_mb.setter
    def volume_capacity_mb(self, volume_capacity_mb):
        """Sets the volume_capacity_mb of this InlineResponse200240ResponseSnapshots.


        :param volume_capacity_mb: The volume_capacity_mb of this InlineResponse200240ResponseSnapshots.  # noqa: E501
        :type: int
        """

        self._volume_capacity_mb = volume_capacity_mb

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200240ResponseSnapshots, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200240ResponseSnapshots):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200240ResponseSnapshots):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class CreateRosBackupJob(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'destination': 'str',
        'volume': 'str',
        'policy': 'str',
        'compression': 'str',
        'sse': 'str',
        'storage_class': 'str'
    }

    attribute_map = {
        'name': 'name',
        'destination': 'destination',
        'volume': 'volume',
        'policy': 'policy',
        'compression': 'compression',
        'sse': 'sse',
        'storage_class': 'storage_class'
    }

    def __init__(self, name=None, destination=None, volume=None, policy=None, compression=None, sse=None, storage_class=None, _configuration=None):  # noqa: E501
        """CreateRosBackupJob - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._destination = None
        self._volume = None
        self._policy = None
        self._compression = None
        self._sse = None
        self._storage_class = None
        self.discriminator = None

        self.name = name
        self.destination = destination
        self.volume = volume
        self.policy = policy
        self.compression = compression
        self.sse = sse
        if storage_class is not None:
            self.storage_class = storage_class

    @property
    def name(self):
        """Gets the name of this CreateRosBackupJob.  # noqa: E501

        Display Name for object storage backup job  # noqa: E501

        :return: The name of this CreateRosBackupJob.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateRosBackupJob.

        Display Name for object storage backup job  # noqa: E501

        :param name: The name of this CreateRosBackupJob.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def destination(self):
        """Gets the destination of this CreateRosBackupJob.  # noqa: E501

        Object storage destination for the backup  # noqa: E501

        :return: The destination of this CreateRosBackupJob.  # noqa: E501
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this CreateRosBackupJob.

        Object storage destination for the backup  # noqa: E501

        :param destination: The destination of this CreateRosBackupJob.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and destination is None:
            raise ValueError("Invalid value for `destination`, must not be `None`")  # noqa: E501

        self._destination = destination

    @property
    def volume(self):
        """Gets the volume of this CreateRosBackupJob.  # noqa: E501

        Volume to backup  # noqa: E501

        :return: The volume of this CreateRosBackupJob.  # noqa: E501
        :rtype: str
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this CreateRosBackupJob.

        Volume to backup  # noqa: E501

        :param volume: The volume of this CreateRosBackupJob.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and volume is None:
            raise ValueError("Invalid value for `volume`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                volume is not None and not re.search(r'^volume-[0-9a-f]{8}$', volume)):  # noqa: E501
            raise ValueError(r"Invalid value for `volume`, must be a follow pattern or equal to `/^volume-[0-9a-f]{8}$/`")  # noqa: E501

        self._volume = volume

    @property
    def policy(self):
        """Gets the policy of this CreateRosBackupJob.  # noqa: E501

        snapshot policy for backup  # noqa: E501

        :return: The policy of this CreateRosBackupJob.  # noqa: E501
        :rtype: str
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this CreateRosBackupJob.

        snapshot policy for backup  # noqa: E501

        :param policy: The policy of this CreateRosBackupJob.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and policy is None:
            raise ValueError("Invalid value for `policy`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                policy is not None and not re.search(r'^policy-[0-9a-f]{8}$', policy)):  # noqa: E501
            raise ValueError(r"Invalid value for `policy`, must be a follow pattern or equal to `/^policy-[0-9a-f]{8}$/`")  # noqa: E501

        self._policy = policy

    @property
    def compression(self):
        """Gets the compression of this CreateRosBackupJob.  # noqa: E501

        enable compression  # noqa: E501

        :return: The compression of this CreateRosBackupJob.  # noqa: E501
        :rtype: str
        """
        return self._compression

    @compression.setter
    def compression(self, compression):
        """Sets the compression of this CreateRosBackupJob.

        enable compression  # noqa: E501

        :param compression: The compression of this CreateRosBackupJob.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and compression is None:
            raise ValueError("Invalid value for `compression`, must not be `None`")  # noqa: E501
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                compression not in allowed_values):
            raise ValueError(
                "Invalid value for `compression` ({0}), must be one of {1}"  # noqa: E501
                .format(compression, allowed_values)
            )

        self._compression = compression

    @property
    def sse(self):
        """Gets the sse of this CreateRosBackupJob.  # noqa: E501

        SSE - use 'NO' for Azure cloud.  # noqa: E501

        :return: The sse of this CreateRosBackupJob.  # noqa: E501
        :rtype: str
        """
        return self._sse

    @sse.setter
    def sse(self, sse):
        """Sets the sse of this CreateRosBackupJob.

        SSE - use 'NO' for Azure cloud.  # noqa: E501

        :param sse: The sse of this CreateRosBackupJob.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and sse is None:
            raise ValueError("Invalid value for `sse`, must not be `None`")  # noqa: E501
        allowed_values = ["NO", "AES256", "KMS", "KMSKEYID"]  # noqa: E501
        if (self._configuration.client_side_validation and
                sse not in allowed_values):
            raise ValueError(
                "Invalid value for `sse` ({0}), must be one of {1}"  # noqa: E501
                .format(sse, allowed_values)
            )

        self._sse = sse

    @property
    def storage_class(self):
        """Gets the storage_class of this CreateRosBackupJob.  # noqa: E501

        S3 storage class if the object storage destination is AWS S3 (STANDARD, INTELLIGENT_TIERING or STANDARD_IA), default is what configured on the bucket. Or BLOB storage tier for Azure cloud (HOT or COOL).  # noqa: E501

        :return: The storage_class of this CreateRosBackupJob.  # noqa: E501
        :rtype: str
        """
        return self._storage_class

    @storage_class.setter
    def storage_class(self, storage_class):
        """Sets the storage_class of this CreateRosBackupJob.

        S3 storage class if the object storage destination is AWS S3 (STANDARD, INTELLIGENT_TIERING or STANDARD_IA), default is what configured on the bucket. Or BLOB storage tier for Azure cloud (HOT or COOL).  # noqa: E501

        :param storage_class: The storage_class of this CreateRosBackupJob.  # noqa: E501
        :type: str
        """
        allowed_values = ["STANDARD", "INTELLIGENT_TIERING", "STANDARD_IA", "HOT", "COOL"]  # noqa: E501
        if (self._configuration.client_side_validation and
                storage_class not in allowed_values):
            raise ValueError(
                "Invalid value for `storage_class` ({0}), must be one of {1}"  # noqa: E501
                .format(storage_class, allowed_values)
            )

        self._storage_class = storage_class

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateRosBackupJob, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateRosBackupJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateRosBackupJob):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20018Drives(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'device_name': 'str',
        'uuid': 'str',
        'storage_node': 'str',
        'drive_type': 'str',
        'absent': 'str',
        'capacity': 'int',
        'licensed': 'bool',
        'status': 'str',
        'address': 'str',
        'pci_address': 'str',
        'location': 'str',
        'product_id': 'str',
        'serial_num': 'str',
        'fw_version': 'str',
        'target_fw_ver': 'str',
        'upgrade_recommended': 'bool',
        'cache': 'bool',
        'enabled': 'bool',
        'vpsa_internal_name': 'str',
        'volume': 'str'
    }

    attribute_map = {
        'id': 'id',
        'device_name': 'device_name',
        'uuid': 'uuid',
        'storage_node': 'storage_node',
        'drive_type': 'drive_type',
        'absent': 'absent',
        'capacity': 'capacity',
        'licensed': 'licensed',
        'status': 'status',
        'address': 'address',
        'pci_address': 'pci_address',
        'location': 'location',
        'product_id': 'product_id',
        'serial_num': 'serial_num',
        'fw_version': 'fw_version',
        'target_fw_ver': 'target_fw_ver',
        'upgrade_recommended': 'upgrade_recommended',
        'cache': 'cache',
        'enabled': 'enabled',
        'vpsa_internal_name': 'vpsa_internal_name',
        'volume': 'volume'
    }

    def __init__(self, id=None, device_name=None, uuid=None, storage_node=None, drive_type=None, absent=None, capacity=None, licensed=None, status=None, address=None, pci_address=None, location=None, product_id=None, serial_num=None, fw_version=None, target_fw_ver=None, upgrade_recommended=None, cache=None, enabled=None, vpsa_internal_name=None, volume=None, _configuration=None):  # noqa: E501
        """InlineResponse20018Drives - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._device_name = None
        self._uuid = None
        self._storage_node = None
        self._drive_type = None
        self._absent = None
        self._capacity = None
        self._licensed = None
        self._status = None
        self._address = None
        self._pci_address = None
        self._location = None
        self._product_id = None
        self._serial_num = None
        self._fw_version = None
        self._target_fw_ver = None
        self._upgrade_recommended = None
        self._cache = None
        self._enabled = None
        self._vpsa_internal_name = None
        self._volume = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if device_name is not None:
            self.device_name = device_name
        if uuid is not None:
            self.uuid = uuid
        if storage_node is not None:
            self.storage_node = storage_node
        if drive_type is not None:
            self.drive_type = drive_type
        if absent is not None:
            self.absent = absent
        if capacity is not None:
            self.capacity = capacity
        if licensed is not None:
            self.licensed = licensed
        if status is not None:
            self.status = status
        if address is not None:
            self.address = address
        if pci_address is not None:
            self.pci_address = pci_address
        if location is not None:
            self.location = location
        if product_id is not None:
            self.product_id = product_id
        if serial_num is not None:
            self.serial_num = serial_num
        if fw_version is not None:
            self.fw_version = fw_version
        if target_fw_ver is not None:
            self.target_fw_ver = target_fw_ver
        if upgrade_recommended is not None:
            self.upgrade_recommended = upgrade_recommended
        if cache is not None:
            self.cache = cache
        if enabled is not None:
            self.enabled = enabled
        if vpsa_internal_name is not None:
            self.vpsa_internal_name = vpsa_internal_name
        if volume is not None:
            self.volume = volume

    @property
    def id(self):
        """Gets the id of this InlineResponse20018Drives.  # noqa: E501


        :return: The id of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20018Drives.


        :param id: The id of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def device_name(self):
        """Gets the device_name of this InlineResponse20018Drives.  # noqa: E501


        :return: The device_name of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._device_name

    @device_name.setter
    def device_name(self, device_name):
        """Sets the device_name of this InlineResponse20018Drives.


        :param device_name: The device_name of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._device_name = device_name

    @property
    def uuid(self):
        """Gets the uuid of this InlineResponse20018Drives.  # noqa: E501


        :return: The uuid of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this InlineResponse20018Drives.


        :param uuid: The uuid of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def storage_node(self):
        """Gets the storage_node of this InlineResponse20018Drives.  # noqa: E501


        :return: The storage_node of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._storage_node

    @storage_node.setter
    def storage_node(self, storage_node):
        """Sets the storage_node of this InlineResponse20018Drives.


        :param storage_node: The storage_node of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._storage_node = storage_node

    @property
    def drive_type(self):
        """Gets the drive_type of this InlineResponse20018Drives.  # noqa: E501


        :return: The drive_type of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._drive_type

    @drive_type.setter
    def drive_type(self, drive_type):
        """Sets the drive_type of this InlineResponse20018Drives.


        :param drive_type: The drive_type of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._drive_type = drive_type

    @property
    def absent(self):
        """Gets the absent of this InlineResponse20018Drives.  # noqa: E501


        :return: The absent of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._absent

    @absent.setter
    def absent(self, absent):
        """Sets the absent of this InlineResponse20018Drives.


        :param absent: The absent of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._absent = absent

    @property
    def capacity(self):
        """Gets the capacity of this InlineResponse20018Drives.  # noqa: E501


        :return: The capacity of this InlineResponse20018Drives.  # noqa: E501
        :rtype: int
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this InlineResponse20018Drives.


        :param capacity: The capacity of this InlineResponse20018Drives.  # noqa: E501
        :type: int
        """

        self._capacity = capacity

    @property
    def licensed(self):
        """Gets the licensed of this InlineResponse20018Drives.  # noqa: E501


        :return: The licensed of this InlineResponse20018Drives.  # noqa: E501
        :rtype: bool
        """
        return self._licensed

    @licensed.setter
    def licensed(self, licensed):
        """Sets the licensed of this InlineResponse20018Drives.


        :param licensed: The licensed of this InlineResponse20018Drives.  # noqa: E501
        :type: bool
        """

        self._licensed = licensed

    @property
    def status(self):
        """Gets the status of this InlineResponse20018Drives.  # noqa: E501


        :return: The status of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20018Drives.


        :param status: The status of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def address(self):
        """Gets the address of this InlineResponse20018Drives.  # noqa: E501


        :return: The address of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this InlineResponse20018Drives.


        :param address: The address of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def pci_address(self):
        """Gets the pci_address of this InlineResponse20018Drives.  # noqa: E501


        :return: The pci_address of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._pci_address

    @pci_address.setter
    def pci_address(self, pci_address):
        """Sets the pci_address of this InlineResponse20018Drives.


        :param pci_address: The pci_address of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._pci_address = pci_address

    @property
    def location(self):
        """Gets the location of this InlineResponse20018Drives.  # noqa: E501


        :return: The location of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this InlineResponse20018Drives.


        :param location: The location of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def product_id(self):
        """Gets the product_id of this InlineResponse20018Drives.  # noqa: E501


        :return: The product_id of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._product_id

    @product_id.setter
    def product_id(self, product_id):
        """Sets the product_id of this InlineResponse20018Drives.


        :param product_id: The product_id of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._product_id = product_id

    @property
    def serial_num(self):
        """Gets the serial_num of this InlineResponse20018Drives.  # noqa: E501


        :return: The serial_num of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._serial_num

    @serial_num.setter
    def serial_num(self, serial_num):
        """Sets the serial_num of this InlineResponse20018Drives.


        :param serial_num: The serial_num of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._serial_num = serial_num

    @property
    def fw_version(self):
        """Gets the fw_version of this InlineResponse20018Drives.  # noqa: E501


        :return: The fw_version of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._fw_version

    @fw_version.setter
    def fw_version(self, fw_version):
        """Sets the fw_version of this InlineResponse20018Drives.


        :param fw_version: The fw_version of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._fw_version = fw_version

    @property
    def target_fw_ver(self):
        """Gets the target_fw_ver of this InlineResponse20018Drives.  # noqa: E501


        :return: The target_fw_ver of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._target_fw_ver

    @target_fw_ver.setter
    def target_fw_ver(self, target_fw_ver):
        """Sets the target_fw_ver of this InlineResponse20018Drives.


        :param target_fw_ver: The target_fw_ver of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._target_fw_ver = target_fw_ver

    @property
    def upgrade_recommended(self):
        """Gets the upgrade_recommended of this InlineResponse20018Drives.  # noqa: E501


        :return: The upgrade_recommended of this InlineResponse20018Drives.  # noqa: E501
        :rtype: bool
        """
        return self._upgrade_recommended

    @upgrade_recommended.setter
    def upgrade_recommended(self, upgrade_recommended):
        """Sets the upgrade_recommended of this InlineResponse20018Drives.


        :param upgrade_recommended: The upgrade_recommended of this InlineResponse20018Drives.  # noqa: E501
        :type: bool
        """

        self._upgrade_recommended = upgrade_recommended

    @property
    def cache(self):
        """Gets the cache of this InlineResponse20018Drives.  # noqa: E501


        :return: The cache of this InlineResponse20018Drives.  # noqa: E501
        :rtype: bool
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InlineResponse20018Drives.


        :param cache: The cache of this InlineResponse20018Drives.  # noqa: E501
        :type: bool
        """

        self._cache = cache

    @property
    def enabled(self):
        """Gets the enabled of this InlineResponse20018Drives.  # noqa: E501


        :return: The enabled of this InlineResponse20018Drives.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this InlineResponse20018Drives.


        :param enabled: The enabled of this InlineResponse20018Drives.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def vpsa_internal_name(self):
        """Gets the vpsa_internal_name of this InlineResponse20018Drives.  # noqa: E501


        :return: The vpsa_internal_name of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._vpsa_internal_name

    @vpsa_internal_name.setter
    def vpsa_internal_name(self, vpsa_internal_name):
        """Sets the vpsa_internal_name of this InlineResponse20018Drives.


        :param vpsa_internal_name: The vpsa_internal_name of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._vpsa_internal_name = vpsa_internal_name

    @property
    def volume(self):
        """Gets the volume of this InlineResponse20018Drives.  # noqa: E501


        :return: The volume of this InlineResponse20018Drives.  # noqa: E501
        :rtype: str
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this InlineResponse20018Drives.


        :param volume: The volume of this InlineResponse20018Drives.  # noqa: E501
        :type: str
        """

        self._volume = volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20018Drives, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20018Drives):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20018Drives):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from CommandCenter.api_client import ApiClient


class VLANApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_provisioned_vlan_or_range(self, cloud_name, add_provisioned_vlan_or_range, **kwargs):  # noqa: E501
        """add_provisioned_vlan_or_range  # noqa: E501

        Add provisioned vlan or a range to the cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_provisioned_vlan_or_range(cloud_name, add_provisioned_vlan_or_range, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param AddProvisionedVlanOrRange add_provisioned_vlan_or_range: (required)
        :return: InlineResponse20011
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_provisioned_vlan_or_range_with_http_info(cloud_name, add_provisioned_vlan_or_range, **kwargs)  # noqa: E501
        else:
            (data) = self.add_provisioned_vlan_or_range_with_http_info(cloud_name, add_provisioned_vlan_or_range, **kwargs)  # noqa: E501
            return data

    def add_provisioned_vlan_or_range_with_http_info(self, cloud_name, add_provisioned_vlan_or_range, **kwargs):  # noqa: E501
        """add_provisioned_vlan_or_range  # noqa: E501

        Add provisioned vlan or a range to the cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_provisioned_vlan_or_range_with_http_info(cloud_name, add_provisioned_vlan_or_range, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param AddProvisionedVlanOrRange add_provisioned_vlan_or_range: (required)
        :return: InlineResponse20011
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'add_provisioned_vlan_or_range']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_provisioned_vlan_or_range" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `add_provisioned_vlan_or_range`")  # noqa: E501
        # verify the required parameter 'add_provisioned_vlan_or_range' is set
        if self.api_client.client_side_validation and ('add_provisioned_vlan_or_range' not in params or
                                                       params['add_provisioned_vlan_or_range'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `add_provisioned_vlan_or_range` when calling `add_provisioned_vlan_or_range`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_provisioned_vlan_or_range' in params:
            body_params = params['add_provisioned_vlan_or_range']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/vlans.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20011',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def allocate_vlan_to_cloud_user(self, cloud_name, vlan_id, allocate_vlan_to_cloud_user, **kwargs):  # noqa: E501
        """allocate_vlan_to_cloud_user  # noqa: E501

        Allocate vlan to cloud user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.allocate_vlan_to_cloud_user(cloud_name, vlan_id, allocate_vlan_to_cloud_user, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :param AllocateVlanToCloudUser allocate_vlan_to_cloud_user: (required)
        :return: InlineResponse20011
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.allocate_vlan_to_cloud_user_with_http_info(cloud_name, vlan_id, allocate_vlan_to_cloud_user, **kwargs)  # noqa: E501
        else:
            (data) = self.allocate_vlan_to_cloud_user_with_http_info(cloud_name, vlan_id, allocate_vlan_to_cloud_user, **kwargs)  # noqa: E501
            return data

    def allocate_vlan_to_cloud_user_with_http_info(self, cloud_name, vlan_id, allocate_vlan_to_cloud_user, **kwargs):  # noqa: E501
        """allocate_vlan_to_cloud_user  # noqa: E501

        Allocate vlan to cloud user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.allocate_vlan_to_cloud_user_with_http_info(cloud_name, vlan_id, allocate_vlan_to_cloud_user, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :param AllocateVlanToCloudUser allocate_vlan_to_cloud_user: (required)
        :return: InlineResponse20011
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'vlan_id', 'allocate_vlan_to_cloud_user']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method allocate_vlan_to_cloud_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `allocate_vlan_to_cloud_user`")  # noqa: E501
        # verify the required parameter 'vlan_id' is set
        if self.api_client.client_side_validation and ('vlan_id' not in params or
                                                       params['vlan_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vlan_id` when calling `allocate_vlan_to_cloud_user`")  # noqa: E501
        # verify the required parameter 'allocate_vlan_to_cloud_user' is set
        if self.api_client.client_side_validation and ('allocate_vlan_to_cloud_user' not in params or
                                                       params['allocate_vlan_to_cloud_user'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `allocate_vlan_to_cloud_user` when calling `allocate_vlan_to_cloud_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'vlan_id' in params:
            path_params['vlan_id'] = params['vlan_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'allocate_vlan_to_cloud_user' in params:
            body_params = params['allocate_vlan_to_cloud_user']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/vlans/{vlan_id}/allocate.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20011',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def deallocate_vlan_to_cloud_user(self, cloud_name, vlan_id, deallocate_vlan_to_cloud_user, **kwargs):  # noqa: E501
        """deallocate_vlan_to_cloud_user  # noqa: E501

        Deallocate vlan from cloud user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.deallocate_vlan_to_cloud_user(cloud_name, vlan_id, deallocate_vlan_to_cloud_user, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :param DeallocateVlanToCloudUser deallocate_vlan_to_cloud_user: (required)
        :return: InlineResponse20012
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.deallocate_vlan_to_cloud_user_with_http_info(cloud_name, vlan_id, deallocate_vlan_to_cloud_user, **kwargs)  # noqa: E501
        else:
            (data) = self.deallocate_vlan_to_cloud_user_with_http_info(cloud_name, vlan_id, deallocate_vlan_to_cloud_user, **kwargs)  # noqa: E501
            return data

    def deallocate_vlan_to_cloud_user_with_http_info(self, cloud_name, vlan_id, deallocate_vlan_to_cloud_user, **kwargs):  # noqa: E501
        """deallocate_vlan_to_cloud_user  # noqa: E501

        Deallocate vlan from cloud user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.deallocate_vlan_to_cloud_user_with_http_info(cloud_name, vlan_id, deallocate_vlan_to_cloud_user, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :param DeallocateVlanToCloudUser deallocate_vlan_to_cloud_user: (required)
        :return: InlineResponse20012
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'vlan_id', 'deallocate_vlan_to_cloud_user']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method deallocate_vlan_to_cloud_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `deallocate_vlan_to_cloud_user`")  # noqa: E501
        # verify the required parameter 'vlan_id' is set
        if self.api_client.client_side_validation and ('vlan_id' not in params or
                                                       params['vlan_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vlan_id` when calling `deallocate_vlan_to_cloud_user`")  # noqa: E501
        # verify the required parameter 'deallocate_vlan_to_cloud_user' is set
        if self.api_client.client_side_validation and ('deallocate_vlan_to_cloud_user' not in params or
                                                       params['deallocate_vlan_to_cloud_user'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `deallocate_vlan_to_cloud_user` when calling `deallocate_vlan_to_cloud_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'vlan_id' in params:
            path_params['vlan_id'] = params['vlan_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'deallocate_vlan_to_cloud_user' in params:
            body_params = params['deallocate_vlan_to_cloud_user']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/vlans/{vlan_id}/deallocate.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20012',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_vlans(self, cloud_name, vlan_id, **kwargs):  # noqa: E501
        """delete_vlans  # noqa: E501

        Remove provisioned vlan from the cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_vlans(cloud_name, vlan_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_vlans_with_http_info(cloud_name, vlan_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_vlans_with_http_info(cloud_name, vlan_id, **kwargs)  # noqa: E501
            return data

    def delete_vlans_with_http_info(self, cloud_name, vlan_id, **kwargs):  # noqa: E501
        """delete_vlans  # noqa: E501

        Remove provisioned vlan from the cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_vlans_with_http_info(cloud_name, vlan_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'vlan_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_vlans" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `delete_vlans`")  # noqa: E501
        # verify the required parameter 'vlan_id' is set
        if self.api_client.client_side_validation and ('vlan_id' not in params or
                                                       params['vlan_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vlan_id` when calling `delete_vlans`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'vlan_id' in params:
            path_params['vlan_id'] = params['vlan_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/vlans/{vlan_id}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_vrid_from_vlan(self, cloud_name, vlan_id, delete_vrid_from_vlan, **kwargs):  # noqa: E501
        """delete_vrid_from_vlan  # noqa: E501

        Remove VRIDs from vlan.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_vrid_from_vlan(cloud_name, vlan_id, delete_vrid_from_vlan, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :param DeleteVridFromVlan delete_vrid_from_vlan: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_vrid_from_vlan_with_http_info(cloud_name, vlan_id, delete_vrid_from_vlan, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_vrid_from_vlan_with_http_info(cloud_name, vlan_id, delete_vrid_from_vlan, **kwargs)  # noqa: E501
            return data

    def delete_vrid_from_vlan_with_http_info(self, cloud_name, vlan_id, delete_vrid_from_vlan, **kwargs):  # noqa: E501
        """delete_vrid_from_vlan  # noqa: E501

        Remove VRIDs from vlan.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_vrid_from_vlan_with_http_info(cloud_name, vlan_id, delete_vrid_from_vlan, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :param DeleteVridFromVlan delete_vrid_from_vlan: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'vlan_id', 'delete_vrid_from_vlan']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_vrid_from_vlan" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `delete_vrid_from_vlan`")  # noqa: E501
        # verify the required parameter 'vlan_id' is set
        if self.api_client.client_side_validation and ('vlan_id' not in params or
                                                       params['vlan_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vlan_id` when calling `delete_vrid_from_vlan`")  # noqa: E501
        # verify the required parameter 'delete_vrid_from_vlan' is set
        if self.api_client.client_side_validation and ('delete_vrid_from_vlan' not in params or
                                                       params['delete_vrid_from_vlan'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `delete_vrid_from_vlan` when calling `delete_vrid_from_vlan`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'vlan_id' in params:
            path_params['vlan_id'] = params['vlan_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_vrid_from_vlan' in params:
            body_params = params['delete_vrid_from_vlan']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/vlans/{vlan_id}/remove_vrids.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_vlans(self, cloud_name, **kwargs):  # noqa: E501
        """get_vlans  # noqa: E501

        Return the list of cloud provisioned vlans.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vlans(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse20087
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_vlans_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_vlans_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def get_vlans_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """get_vlans  # noqa: E501

        Return the list of cloud provisioned vlans.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vlans_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse20087
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_vlans" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_vlans`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/vlans.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20087',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def populate_vrid_in_vlan(self, cloud_name, vlan_id, populate_vrid_in_vlan, **kwargs):  # noqa: E501
        """populate_vrid_in_vlan  # noqa: E501

        Add VRIDs to vlan.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.populate_vrid_in_vlan(cloud_name, vlan_id, populate_vrid_in_vlan, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :param PopulateVridInVlan populate_vrid_in_vlan: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.populate_vrid_in_vlan_with_http_info(cloud_name, vlan_id, populate_vrid_in_vlan, **kwargs)  # noqa: E501
        else:
            (data) = self.populate_vrid_in_vlan_with_http_info(cloud_name, vlan_id, populate_vrid_in_vlan, **kwargs)  # noqa: E501
            return data

    def populate_vrid_in_vlan_with_http_info(self, cloud_name, vlan_id, populate_vrid_in_vlan, **kwargs):  # noqa: E501
        """populate_vrid_in_vlan  # noqa: E501

        Add VRIDs to vlan.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.populate_vrid_in_vlan_with_http_info(cloud_name, vlan_id, populate_vrid_in_vlan, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :param PopulateVridInVlan populate_vrid_in_vlan: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'vlan_id', 'populate_vrid_in_vlan']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method populate_vrid_in_vlan" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `populate_vrid_in_vlan`")  # noqa: E501
        # verify the required parameter 'vlan_id' is set
        if self.api_client.client_side_validation and ('vlan_id' not in params or
                                                       params['vlan_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vlan_id` when calling `populate_vrid_in_vlan`")  # noqa: E501
        # verify the required parameter 'populate_vrid_in_vlan' is set
        if self.api_client.client_side_validation and ('populate_vrid_in_vlan' not in params or
                                                       params['populate_vrid_in_vlan'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `populate_vrid_in_vlan` when calling `populate_vrid_in_vlan`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'vlan_id' in params:
            path_params['vlan_id'] = params['vlan_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'populate_vrid_in_vlan' in params:
            body_params = params['populate_vrid_in_vlan']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/vlans/{vlan_id}/add_vrids.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def reserve_provisioned_vlan(self, cloud_name, vlan_id, **kwargs):  # noqa: E501
        """reserve_provisioned_vlan  # noqa: E501

        Reserve provisioned vlan.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reserve_provisioned_vlan(cloud_name, vlan_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :return: InlineResponse20088
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.reserve_provisioned_vlan_with_http_info(cloud_name, vlan_id, **kwargs)  # noqa: E501
        else:
            (data) = self.reserve_provisioned_vlan_with_http_info(cloud_name, vlan_id, **kwargs)  # noqa: E501
            return data

    def reserve_provisioned_vlan_with_http_info(self, cloud_name, vlan_id, **kwargs):  # noqa: E501
        """reserve_provisioned_vlan  # noqa: E501

        Reserve provisioned vlan.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reserve_provisioned_vlan_with_http_info(cloud_name, vlan_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :return: InlineResponse20088
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'vlan_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reserve_provisioned_vlan" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `reserve_provisioned_vlan`")  # noqa: E501
        # verify the required parameter 'vlan_id' is set
        if self.api_client.client_side_validation and ('vlan_id' not in params or
                                                       params['vlan_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vlan_id` when calling `reserve_provisioned_vlan`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'vlan_id' in params:
            path_params['vlan_id'] = params['vlan_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/vlans/{vlan_id}/reserve.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20088',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def reserve_vrid_for_vlan(self, cloud_name, vlan_id, reserve_vrid_for_vlan, **kwargs):  # noqa: E501
        """reserve_vrid_for_vlan  # noqa: E501

        Reserve VRID for vlan.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reserve_vrid_for_vlan(cloud_name, vlan_id, reserve_vrid_for_vlan, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :param ReserveVridForVlan reserve_vrid_for_vlan: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.reserve_vrid_for_vlan_with_http_info(cloud_name, vlan_id, reserve_vrid_for_vlan, **kwargs)  # noqa: E501
        else:
            (data) = self.reserve_vrid_for_vlan_with_http_info(cloud_name, vlan_id, reserve_vrid_for_vlan, **kwargs)  # noqa: E501
            return data

    def reserve_vrid_for_vlan_with_http_info(self, cloud_name, vlan_id, reserve_vrid_for_vlan, **kwargs):  # noqa: E501
        """reserve_vrid_for_vlan  # noqa: E501

        Reserve VRID for vlan.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reserve_vrid_for_vlan_with_http_info(cloud_name, vlan_id, reserve_vrid_for_vlan, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :param ReserveVridForVlan reserve_vrid_for_vlan: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'vlan_id', 'reserve_vrid_for_vlan']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reserve_vrid_for_vlan" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `reserve_vrid_for_vlan`")  # noqa: E501
        # verify the required parameter 'vlan_id' is set
        if self.api_client.client_side_validation and ('vlan_id' not in params or
                                                       params['vlan_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vlan_id` when calling `reserve_vrid_for_vlan`")  # noqa: E501
        # verify the required parameter 'reserve_vrid_for_vlan' is set
        if self.api_client.client_side_validation and ('reserve_vrid_for_vlan' not in params or
                                                       params['reserve_vrid_for_vlan'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `reserve_vrid_for_vlan` when calling `reserve_vrid_for_vlan`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'vlan_id' in params:
            path_params['vlan_id'] = params['vlan_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'reserve_vrid_for_vlan' in params:
            body_params = params['reserve_vrid_for_vlan']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/vlans/{vlan_id}/reserve_vrid.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_default_vlan_for_cloud_user(self, cloud_name, vlan_id, set_default_vlan_for_cloud_user, **kwargs):  # noqa: E501
        """set_default_vlan_for_cloud_user  # noqa: E501

        Set default vlan for cloud user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_default_vlan_for_cloud_user(cloud_name, vlan_id, set_default_vlan_for_cloud_user, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :param SetDefaultVlanForCloudUser set_default_vlan_for_cloud_user: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_default_vlan_for_cloud_user_with_http_info(cloud_name, vlan_id, set_default_vlan_for_cloud_user, **kwargs)  # noqa: E501
        else:
            (data) = self.set_default_vlan_for_cloud_user_with_http_info(cloud_name, vlan_id, set_default_vlan_for_cloud_user, **kwargs)  # noqa: E501
            return data

    def set_default_vlan_for_cloud_user_with_http_info(self, cloud_name, vlan_id, set_default_vlan_for_cloud_user, **kwargs):  # noqa: E501
        """set_default_vlan_for_cloud_user  # noqa: E501

        Set default vlan for cloud user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_default_vlan_for_cloud_user_with_http_info(cloud_name, vlan_id, set_default_vlan_for_cloud_user, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :param SetDefaultVlanForCloudUser set_default_vlan_for_cloud_user: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'vlan_id', 'set_default_vlan_for_cloud_user']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_default_vlan_for_cloud_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `set_default_vlan_for_cloud_user`")  # noqa: E501
        # verify the required parameter 'vlan_id' is set
        if self.api_client.client_side_validation and ('vlan_id' not in params or
                                                       params['vlan_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vlan_id` when calling `set_default_vlan_for_cloud_user`")  # noqa: E501
        # verify the required parameter 'set_default_vlan_for_cloud_user' is set
        if self.api_client.client_side_validation and ('set_default_vlan_for_cloud_user' not in params or
                                                       params['set_default_vlan_for_cloud_user'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `set_default_vlan_for_cloud_user` when calling `set_default_vlan_for_cloud_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'vlan_id' in params:
            path_params['vlan_id'] = params['vlan_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'set_default_vlan_for_cloud_user' in params:
            body_params = params['set_default_vlan_for_cloud_user']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/vlans/{vlan_id}/default.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def unreserve_provisioned_vlan(self, cloud_name, vlan_id, **kwargs):  # noqa: E501
        """unreserve_provisioned_vlan  # noqa: E501

        Unreserve provisioned vlan.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unreserve_provisioned_vlan(cloud_name, vlan_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.unreserve_provisioned_vlan_with_http_info(cloud_name, vlan_id, **kwargs)  # noqa: E501
        else:
            (data) = self.unreserve_provisioned_vlan_with_http_info(cloud_name, vlan_id, **kwargs)  # noqa: E501
            return data

    def unreserve_provisioned_vlan_with_http_info(self, cloud_name, vlan_id, **kwargs):  # noqa: E501
        """unreserve_provisioned_vlan  # noqa: E501

        Unreserve provisioned vlan.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unreserve_provisioned_vlan_with_http_info(cloud_name, vlan_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'vlan_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method unreserve_provisioned_vlan" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `unreserve_provisioned_vlan`")  # noqa: E501
        # verify the required parameter 'vlan_id' is set
        if self.api_client.client_side_validation and ('vlan_id' not in params or
                                                       params['vlan_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vlan_id` when calling `unreserve_provisioned_vlan`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'vlan_id' in params:
            path_params['vlan_id'] = params['vlan_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/vlans/{vlan_id}/unreserve.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def unreserve_vrid_from_vlan(self, cloud_name, vlan_id, unreserve_vrid_from_vlan, **kwargs):  # noqa: E501
        """unreserve_vrid_from_vlan  # noqa: E501

        Unreserve VRID from vlan.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unreserve_vrid_from_vlan(cloud_name, vlan_id, unreserve_vrid_from_vlan, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :param UnreserveVridFromVlan unreserve_vrid_from_vlan: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.unreserve_vrid_from_vlan_with_http_info(cloud_name, vlan_id, unreserve_vrid_from_vlan, **kwargs)  # noqa: E501
        else:
            (data) = self.unreserve_vrid_from_vlan_with_http_info(cloud_name, vlan_id, unreserve_vrid_from_vlan, **kwargs)  # noqa: E501
            return data

    def unreserve_vrid_from_vlan_with_http_info(self, cloud_name, vlan_id, unreserve_vrid_from_vlan, **kwargs):  # noqa: E501
        """unreserve_vrid_from_vlan  # noqa: E501

        Unreserve VRID from vlan.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unreserve_vrid_from_vlan_with_http_info(cloud_name, vlan_id, unreserve_vrid_from_vlan, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str vlan_id: (required)
        :param UnreserveVridFromVlan unreserve_vrid_from_vlan: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'vlan_id', 'unreserve_vrid_from_vlan']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method unreserve_vrid_from_vlan" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `unreserve_vrid_from_vlan`")  # noqa: E501
        # verify the required parameter 'vlan_id' is set
        if self.api_client.client_side_validation and ('vlan_id' not in params or
                                                       params['vlan_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vlan_id` when calling `unreserve_vrid_from_vlan`")  # noqa: E501
        # verify the required parameter 'unreserve_vrid_from_vlan' is set
        if self.api_client.client_side_validation and ('unreserve_vrid_from_vlan' not in params or
                                                       params['unreserve_vrid_from_vlan'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `unreserve_vrid_from_vlan` when calling `unreserve_vrid_from_vlan`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'vlan_id' in params:
            path_params['vlan_id'] = params['vlan_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'unreserve_vrid_from_vlan' in params:
            body_params = params['unreserve_vrid_from_vlan']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/vlans/{vlan_id}/unreserve_vrid.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from CommandCenter.api_client import ApiClient


class SoftwareInstallApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def abort_last_action(self, cloud_name, **kwargs):  # noqa: E501
        """abort_last_action  # noqa: E501

        Abort last Install action.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.abort_last_action(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse20081
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.abort_last_action_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.abort_last_action_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def abort_last_action_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """abort_last_action  # noqa: E501

        Abort last Install action.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.abort_last_action_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse20081
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method abort_last_action" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `abort_last_action`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/software_install/abort_last_action.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20081',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cloud_upgrade(self, cloud_name, cloud_upgrade, **kwargs):  # noqa: E501
        """cloud_upgrade  # noqa: E501

        Upgrade the selected compoments (SN\\VPSA\\CCVM) in the Zadara Cloud to the specified software package. If no components are passed, all components will be upgraded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cloud_upgrade(cloud_name, cloud_upgrade, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param CloudUpgrade cloud_upgrade: (required)
        :return: InlineResponse20079
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cloud_upgrade_with_http_info(cloud_name, cloud_upgrade, **kwargs)  # noqa: E501
        else:
            (data) = self.cloud_upgrade_with_http_info(cloud_name, cloud_upgrade, **kwargs)  # noqa: E501
            return data

    def cloud_upgrade_with_http_info(self, cloud_name, cloud_upgrade, **kwargs):  # noqa: E501
        """cloud_upgrade  # noqa: E501

        Upgrade the selected compoments (SN\\VPSA\\CCVM) in the Zadara Cloud to the specified software package. If no components are passed, all components will be upgraded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cloud_upgrade_with_http_info(cloud_name, cloud_upgrade, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param CloudUpgrade cloud_upgrade: (required)
        :return: InlineResponse20079
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'cloud_upgrade']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cloud_upgrade" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `cloud_upgrade`")  # noqa: E501
        # verify the required parameter 'cloud_upgrade' is set
        if self.api_client.client_side_validation and ('cloud_upgrade' not in params or
                                                       params['cloud_upgrade'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_upgrade` when calling `cloud_upgrade`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'cloud_upgrade' in params:
            body_params = params['cloud_upgrade']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/software_install/cloud_upgrade.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20079',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def download_package(self, cloud_name, download_package, **kwargs):  # noqa: E501
        """download_package  # noqa: E501

        Download and Install package from a remote repository. If remote_repo is not defined, the default Zadara repo is used.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_package(cloud_name, download_package, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param DownloadPackage download_package: (required)
        :return: InlineResponse20077
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.download_package_with_http_info(cloud_name, download_package, **kwargs)  # noqa: E501
        else:
            (data) = self.download_package_with_http_info(cloud_name, download_package, **kwargs)  # noqa: E501
            return data

    def download_package_with_http_info(self, cloud_name, download_package, **kwargs):  # noqa: E501
        """download_package  # noqa: E501

        Download and Install package from a remote repository. If remote_repo is not defined, the default Zadara repo is used.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_package_with_http_info(cloud_name, download_package, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param DownloadPackage download_package: (required)
        :return: InlineResponse20077
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'download_package']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_package" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `download_package`")  # noqa: E501
        # verify the required parameter 'download_package' is set
        if self.api_client.client_side_validation and ('download_package' not in params or
                                                       params['download_package'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `download_package` when calling `download_package`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'download_package' in params:
            body_params = params['download_package']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/software_install/download_package.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20077',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def erase_package(self, cloud_name, erase_package, **kwargs):  # noqa: E501
        """erase_package  # noqa: E501

        Erase package from the local repository.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.erase_package(cloud_name, erase_package, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param ErasePackage erase_package: (required)
        :return: InlineResponse20078
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.erase_package_with_http_info(cloud_name, erase_package, **kwargs)  # noqa: E501
        else:
            (data) = self.erase_package_with_http_info(cloud_name, erase_package, **kwargs)  # noqa: E501
            return data

    def erase_package_with_http_info(self, cloud_name, erase_package, **kwargs):  # noqa: E501
        """erase_package  # noqa: E501

        Erase package from the local repository.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.erase_package_with_http_info(cloud_name, erase_package, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param ErasePackage erase_package: (required)
        :return: InlineResponse20078
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'erase_package']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method erase_package" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `erase_package`")  # noqa: E501
        # verify the required parameter 'erase_package' is set
        if self.api_client.client_side_validation and ('erase_package' not in params or
                                                       params['erase_package'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `erase_package` when calling `erase_package`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'erase_package' in params:
            body_params = params['erase_package']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/software_install/erase_package.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20078',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_packages(self, cloud_name, **kwargs):  # noqa: E501
        """list_packages  # noqa: E501

        Lists Install packages. Shows packages from local and renote repository. If remote_repo is not defined, the default Zadara repo is used.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_packages(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str remote_repo: Remote repository
        :return: InlineResponse20076
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_packages_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.list_packages_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def list_packages_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """list_packages  # noqa: E501

        Lists Install packages. Shows packages from local and renote repository. If remote_repo is not defined, the default Zadara repo is used.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_packages_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str remote_repo: Remote repository
        :return: InlineResponse20076
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'remote_repo']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_packages" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `list_packages`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []
        if 'remote_repo' in params:
            query_params.append(('remote_repo', params['remote_repo']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/software_install/list_packages.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20076',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_sns(self, cloud_name, **kwargs):  # noqa: E501
        """list_sns  # noqa: E501

        Lists Storage Nodes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_sns(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse20075
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_sns_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.list_sns_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def list_sns_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """list_sns  # noqa: E501

        Lists Storage Nodes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_sns_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse20075
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_sns" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `list_sns`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/software_install/list_sns.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20075',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def register_images(self, cloud_name, register_images, **kwargs):  # noqa: E501
        """register_images  # noqa: E501

        Register image in the local repository.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_images(cloud_name, register_images, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param RegisterImages register_images: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.register_images_with_http_info(cloud_name, register_images, **kwargs)  # noqa: E501
        else:
            (data) = self.register_images_with_http_info(cloud_name, register_images, **kwargs)  # noqa: E501
            return data

    def register_images_with_http_info(self, cloud_name, register_images, **kwargs):  # noqa: E501
        """register_images  # noqa: E501

        Register image in the local repository.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_images_with_http_info(cloud_name, register_images, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param RegisterImages register_images: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'register_images']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method register_images" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `register_images`")  # noqa: E501
        # verify the required parameter 'register_images' is set
        if self.api_client.client_side_validation and ('register_images' not in params or
                                                       params['register_images'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `register_images` when calling `register_images`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'register_images' in params:
            body_params = params['register_images']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/software_install/register_images.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def restart_last_action(self, cloud_name, **kwargs):  # noqa: E501
        """restart_last_action  # noqa: E501

        Restart last failing Install action.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.restart_last_action(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse20082
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.restart_last_action_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.restart_last_action_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def restart_last_action_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """restart_last_action  # noqa: E501

        Restart last failing Install action.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.restart_last_action_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse20082
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method restart_last_action" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `restart_last_action`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/software_install/restart_last_action.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20082',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def show_all(self, cloud_name, **kwargs):  # noqa: E501
        """show_all  # noqa: E501

        Show history of Install actions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_all(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse20080
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.show_all_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.show_all_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def show_all_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """show_all  # noqa: E501

        Show history of Install actions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_all_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse20080
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method show_all" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `show_all`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/software_install/show_all.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20080',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def sn_install(self, cloud_name, sn_install, **kwargs):  # noqa: E501
        """sn_install  # noqa: E501

        Install a new Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.sn_install(cloud_name, sn_install, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param SnInstall sn_install: (required)
        :return: InlineResponse20079
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.sn_install_with_http_info(cloud_name, sn_install, **kwargs)  # noqa: E501
        else:
            (data) = self.sn_install_with_http_info(cloud_name, sn_install, **kwargs)  # noqa: E501
            return data

    def sn_install_with_http_info(self, cloud_name, sn_install, **kwargs):  # noqa: E501
        """sn_install  # noqa: E501

        Install a new Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.sn_install_with_http_info(cloud_name, sn_install, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param SnInstall sn_install: (required)
        :return: InlineResponse20079
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'sn_install']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method sn_install" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `sn_install`")  # noqa: E501
        # verify the required parameter 'sn_install' is set
        if self.api_client.client_side_validation and ('sn_install' not in params or
                                                       params['sn_install'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `sn_install` when calling `sn_install`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'sn_install' in params:
            body_params = params['sn_install']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/software_install/sn_install.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20079',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_settings(self, cloud_name, file, **kwargs):  # noqa: E501
        """upload_settings  # noqa: E501

        Upload deb settings file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_settings(cloud_name, file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param file file: .deb file upload (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upload_settings_with_http_info(cloud_name, file, **kwargs)  # noqa: E501
        else:
            (data) = self.upload_settings_with_http_info(cloud_name, file, **kwargs)  # noqa: E501
            return data

    def upload_settings_with_http_info(self, cloud_name, file, **kwargs):  # noqa: E501
        """upload_settings  # noqa: E501

        Upload deb settings file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_settings_with_http_info(cloud_name, file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param file file: .deb file upload (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_settings" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `upload_settings`")  # noqa: E501
        # verify the required parameter 'file' is set
        if self.api_client.client_side_validation and ('file' not in params or
                                                       params['file'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `file` when calling `upload_settings`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in params:
            local_var_files['file'] = params['file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/software_install/upload_settings.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from CommandCenter.api.access_logs_api import AccessLogsApi
from CommandCenter.api.cloud_settings_api import CloudSettingsApi
from CommandCenter.api.cloud_users_api import CloudUsersApi
from CommandCenter.api.clouds_api import CloudsApi
from CommandCenter.api.comments_api import CommentsApi
from CommandCenter.api.computes_api import ComputesApi
from CommandCenter.api.custom_networks_api import CustomNetworksApi
from CommandCenter.api.drive_api import DriveApi
from CommandCenter.api.drive_types_api import DriveTypesApi
from CommandCenter.api.engine_types_api import EngineTypesApi
from CommandCenter.api.fault_domains_api import FaultDomainsApi
from CommandCenter.api.images_api import ImagesApi
from CommandCenter.api.logs_api import LogsApi
from CommandCenter.api.remote_authentications_api import RemoteAuthenticationsApi
from CommandCenter.api.roles_api import RolesApi
from CommandCenter.api.software_install_api import SoftwareInstallApi
from CommandCenter.api.storage_nodes_api import StorageNodesApi
from CommandCenter.api.users_api import UsersApi
from CommandCenter.api.vlan_api import VLANApi
from CommandCenter.api.vpsa_api import VPSAApi
from CommandCenter.api.vpsa_object_storage_api import VPSAObjectStorageApi
from CommandCenter.api.volume_api import VolumeApi



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse2001Resources(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'used_memory': 'int',
        'total_memory': 'int',
        'used_vcpus': 'int',
        'total_vcpus': 'int',
        'used_drives': 'int',
        'total_drives': 'int',
        'used_capacity': 'int',
        'total_capacity': 'int',
        'used_cache': 'int',
        'total_cache': 'int'
    }

    attribute_map = {
        'used_memory': 'used_memory',
        'total_memory': 'total_memory',
        'used_vcpus': 'used_vcpus',
        'total_vcpus': 'total_vcpus',
        'used_drives': 'used_drives',
        'total_drives': 'total_drives',
        'used_capacity': 'used_capacity',
        'total_capacity': 'total_capacity',
        'used_cache': 'used_cache',
        'total_cache': 'total_cache'
    }

    def __init__(self, used_memory=None, total_memory=None, used_vcpus=None, total_vcpus=None, used_drives=None, total_drives=None, used_capacity=None, total_capacity=None, used_cache=None, total_cache=None, _configuration=None):  # noqa: E501
        """InlineResponse2001Resources - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._used_memory = None
        self._total_memory = None
        self._used_vcpus = None
        self._total_vcpus = None
        self._used_drives = None
        self._total_drives = None
        self._used_capacity = None
        self._total_capacity = None
        self._used_cache = None
        self._total_cache = None
        self.discriminator = None

        if used_memory is not None:
            self.used_memory = used_memory
        if total_memory is not None:
            self.total_memory = total_memory
        if used_vcpus is not None:
            self.used_vcpus = used_vcpus
        if total_vcpus is not None:
            self.total_vcpus = total_vcpus
        if used_drives is not None:
            self.used_drives = used_drives
        if total_drives is not None:
            self.total_drives = total_drives
        if used_capacity is not None:
            self.used_capacity = used_capacity
        if total_capacity is not None:
            self.total_capacity = total_capacity
        if used_cache is not None:
            self.used_cache = used_cache
        if total_cache is not None:
            self.total_cache = total_cache

    @property
    def used_memory(self):
        """Gets the used_memory of this InlineResponse2001Resources.  # noqa: E501


        :return: The used_memory of this InlineResponse2001Resources.  # noqa: E501
        :rtype: int
        """
        return self._used_memory

    @used_memory.setter
    def used_memory(self, used_memory):
        """Sets the used_memory of this InlineResponse2001Resources.


        :param used_memory: The used_memory of this InlineResponse2001Resources.  # noqa: E501
        :type: int
        """

        self._used_memory = used_memory

    @property
    def total_memory(self):
        """Gets the total_memory of this InlineResponse2001Resources.  # noqa: E501


        :return: The total_memory of this InlineResponse2001Resources.  # noqa: E501
        :rtype: int
        """
        return self._total_memory

    @total_memory.setter
    def total_memory(self, total_memory):
        """Sets the total_memory of this InlineResponse2001Resources.


        :param total_memory: The total_memory of this InlineResponse2001Resources.  # noqa: E501
        :type: int
        """

        self._total_memory = total_memory

    @property
    def used_vcpus(self):
        """Gets the used_vcpus of this InlineResponse2001Resources.  # noqa: E501


        :return: The used_vcpus of this InlineResponse2001Resources.  # noqa: E501
        :rtype: int
        """
        return self._used_vcpus

    @used_vcpus.setter
    def used_vcpus(self, used_vcpus):
        """Sets the used_vcpus of this InlineResponse2001Resources.


        :param used_vcpus: The used_vcpus of this InlineResponse2001Resources.  # noqa: E501
        :type: int
        """

        self._used_vcpus = used_vcpus

    @property
    def total_vcpus(self):
        """Gets the total_vcpus of this InlineResponse2001Resources.  # noqa: E501


        :return: The total_vcpus of this InlineResponse2001Resources.  # noqa: E501
        :rtype: int
        """
        return self._total_vcpus

    @total_vcpus.setter
    def total_vcpus(self, total_vcpus):
        """Sets the total_vcpus of this InlineResponse2001Resources.


        :param total_vcpus: The total_vcpus of this InlineResponse2001Resources.  # noqa: E501
        :type: int
        """

        self._total_vcpus = total_vcpus

    @property
    def used_drives(self):
        """Gets the used_drives of this InlineResponse2001Resources.  # noqa: E501


        :return: The used_drives of this InlineResponse2001Resources.  # noqa: E501
        :rtype: int
        """
        return self._used_drives

    @used_drives.setter
    def used_drives(self, used_drives):
        """Sets the used_drives of this InlineResponse2001Resources.


        :param used_drives: The used_drives of this InlineResponse2001Resources.  # noqa: E501
        :type: int
        """

        self._used_drives = used_drives

    @property
    def total_drives(self):
        """Gets the total_drives of this InlineResponse2001Resources.  # noqa: E501


        :return: The total_drives of this InlineResponse2001Resources.  # noqa: E501
        :rtype: int
        """
        return self._total_drives

    @total_drives.setter
    def total_drives(self, total_drives):
        """Sets the total_drives of this InlineResponse2001Resources.


        :param total_drives: The total_drives of this InlineResponse2001Resources.  # noqa: E501
        :type: int
        """

        self._total_drives = total_drives

    @property
    def used_capacity(self):
        """Gets the used_capacity of this InlineResponse2001Resources.  # noqa: E501


        :return: The used_capacity of this InlineResponse2001Resources.  # noqa: E501
        :rtype: int
        """
        return self._used_capacity

    @used_capacity.setter
    def used_capacity(self, used_capacity):
        """Sets the used_capacity of this InlineResponse2001Resources.


        :param used_capacity: The used_capacity of this InlineResponse2001Resources.  # noqa: E501
        :type: int
        """

        self._used_capacity = used_capacity

    @property
    def total_capacity(self):
        """Gets the total_capacity of this InlineResponse2001Resources.  # noqa: E501


        :return: The total_capacity of this InlineResponse2001Resources.  # noqa: E501
        :rtype: int
        """
        return self._total_capacity

    @total_capacity.setter
    def total_capacity(self, total_capacity):
        """Sets the total_capacity of this InlineResponse2001Resources.


        :param total_capacity: The total_capacity of this InlineResponse2001Resources.  # noqa: E501
        :type: int
        """

        self._total_capacity = total_capacity

    @property
    def used_cache(self):
        """Gets the used_cache of this InlineResponse2001Resources.  # noqa: E501


        :return: The used_cache of this InlineResponse2001Resources.  # noqa: E501
        :rtype: int
        """
        return self._used_cache

    @used_cache.setter
    def used_cache(self, used_cache):
        """Sets the used_cache of this InlineResponse2001Resources.


        :param used_cache: The used_cache of this InlineResponse2001Resources.  # noqa: E501
        :type: int
        """

        self._used_cache = used_cache

    @property
    def total_cache(self):
        """Gets the total_cache of this InlineResponse2001Resources.  # noqa: E501


        :return: The total_cache of this InlineResponse2001Resources.  # noqa: E501
        :rtype: int
        """
        return self._total_cache

    @total_cache.setter
    def total_cache(self, total_cache):
        """Sets the total_cache of this InlineResponse2001Resources.


        :param total_cache: The total_cache of this InlineResponse2001Resources.  # noqa: E501
        :type: int
        """

        self._total_cache = total_cache

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse2001Resources, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2001Resources):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2001Resources):
            return True

        return self.to_dict() != other.to_dict()
